@@ -1,12 +1,17 @@
 package  # hide from PAUSE
    P9Y::ProcessTable;
 
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 #############################################################################
 # Modules
 
-use sanity;
+# use sanity;
+use strict qw(subs vars);
+no strict 'refs';
+use warnings FATAL => 'all';
+no warnings qw(uninitialized);
+
 use Moo;
 use P9Y::ProcessTable::Process;
 
@@ -22,7 +27,7 @@ no warnings 'redefine';
 
 sub table {
    my $self = shift;
-   return map { 
+   return map {
       my $hash = $self->_convert_hash($_);
       $hash->{_pt_obj} = $self;
       P9Y::ProcessTable::Process->new($hash);
@@ -50,21 +55,21 @@ sub _process_hash {
 sub _convert_hash {
    my ($self, $info) = @_;
    return unless $info;
-   
+
    my $hash = {};
-   state $stat_loc = { qw/
+   my $stat_loc = { qw/
       pid        owner_pid
       sess       owner_sid
       cmdline    title
    / };
-   
+
    foreach my $key (keys %$stat_loc) {
       my $item = $info->{ $stat_loc->{$key} };
       $hash->{$key} = $item if defined $item;
    }
-      
+
    $hash->{ppid} = ppidOf($hash->{pid});
-   
+
    return $hash;
 }
 
